Method: Aws::CloudControlApi::Client#create_resource
- Defined in:
- lib/aws-sdk-cloudcontrolapi/client.rb
#create_resource(params = {}) ⇒ Types::CreateResourceOutput
Creates the specified resource. For more information, see Creating a resource in the Amazon Web Services Cloud Control API User Guide.
After you have initiated a resource creation request, you can monitor
the progress of your request by calling GetResourceRequestStatus
using the RequestToken of the ProgressEvent type returned by
CreateResource.
657 658 659 660 |
# File 'lib/aws-sdk-cloudcontrolapi/client.rb', line 657 def create_resource(params = {}, = {}) req = build_request(:create_resource, params) req.send_request() end |