Class: Aws::CloudControlApi::Waiters::ResourceRequestSuccess

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-cloudcontrolapi/waiters.rb,
sig/waiters.rbs

Overview

Wait until resource operation request is successful

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ResourceRequestSuccess

Returns a new instance of ResourceRequestSuccess.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 24
  • :delay (Integer) — default: 5
  • :before_attempt (Proc)
  • :before_wait (Proc)


85
86
# File 'lib/aws-sdk-cloudcontrolapi/waiters.rb', line 85

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



123
124
125
# File 'lib/aws-sdk-cloudcontrolapi/waiters.rb', line 123

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetResourceRequestStatusOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :request_token (required, String)

    A unique token used to track the progress of the resource operation request.

    Request tokens are included in the ProgressEvent type returned by a resource operation request.

Returns:



118
# File 'lib/aws-sdk-cloudcontrolapi/waiters.rb', line 118

def wait: (